/*
 *  Copyright (C) 2018 KeePassXC Team <team@keepassxc.org>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 or (at your option)
 *  version 3 of the License.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef KEEPASSXC_TESTPASSWORDGENERATOR_H
#define KEEPASSXC_TESTPASSWORDGENERATOR_H

#include "core/PasswordGenerator.h"
#include <QObject>

class TestPasswordGenerator : public QObject
{
    Q_OBJECT

private:
    PasswordGenerator m_generator;

private slots:
    void initTestCase();
    void init();

    void testCustomCharacterSet_data();
    void testCustomCharacterSet();
    void testCharClasses_data();
    void testCharClasses();
    void testLookalikeExclusion_data();
    void testLookalikeExclusion();
    void testMinLength_data();
    void testMinLength();
    void testValidity_data();
    void testValidity();
    void testReset();
};

#endif // KEEPASSXC_TESTPASSWORDGENERATOR_H
